@@ -35,9 +35,9 @@ import (
 	tspb "google.golang.org/protobuf/types/known/timestamppb"
 
 	api "github.com/osrg/gobgp/v3/api"
-	"github.com/osrg/gobgp/v3/internal/pkg/config"
 	"github.com/osrg/gobgp/v3/internal/pkg/table"
 	"github.com/osrg/gobgp/v3/pkg/apiutil"
+	"github.com/osrg/gobgp/v3/pkg/config/oc"
 	"github.com/osrg/gobgp/v3/pkg/log"
 	"github.com/osrg/gobgp/v3/pkg/packet/bgp"
 )
@@ -272,8 +272,8 @@ func (s *server) SetPolicies(ctx context.Context, r *api.SetPoliciesRequest) (*e
 	return &emptypb.Empty{}, s.bgpServer.SetPolicies(ctx, r)
 }
 
-func newRoutingPolicyFromApiStruct(arg *api.SetPoliciesRequest) (*config.RoutingPolicy, error) {
-	policyDefinitions := make([]config.PolicyDefinition, 0, len(arg.Policies))
+func newRoutingPolicyFromApiStruct(arg *api.SetPoliciesRequest) (*oc.RoutingPolicy, error) {
+	policyDefinitions := make([]oc.PolicyDefinition, 0, len(arg.Policies))
 	for _, p := range arg.Policies {
 		pd, err := newConfigPolicyFromApiStruct(p)
 		if err != nil {
@@ -287,7 +287,7 @@ func newRoutingPolicyFromApiStruct(arg *api.SetPoliciesRequest) (*config.Routing
 		return nil, err
 	}
 
-	return &config.RoutingPolicy{
+	return &oc.RoutingPolicy{
 		DefinedSets:       *definedSets,
 		PolicyDefinitions: policyDefinitions,
 	}, nil
@@ -501,7 +501,7 @@ func (s *server) DeleteVrf(ctx context.Context, r *api.DeleteVrfRequest) (*empty
 	return &emptypb.Empty{}, s.bgpServer.DeleteVrf(ctx, r)
 }
 
-func readMpGracefulRestartFromAPIStruct(c *config.MpGracefulRestart, a *api.MpGracefulRestart) {
+func readMpGracefulRestartFromAPIStruct(c *oc.MpGracefulRestart, a *api.MpGracefulRestart) {
 	if c == nil || a == nil {
 		return
 	}
@@ -510,16 +510,16 @@ func readMpGracefulRestartFromAPIStruct(c *config.MpGracefulRestart, a *api.MpGr
 	}
 }
 
-func readAfiSafiConfigFromAPIStruct(c *config.AfiSafiConfig, a *api.AfiSafiConfig) {
+func readAfiSafiConfigFromAPIStruct(c *oc.AfiSafiConfig, a *api.AfiSafiConfig) {
 	if c == nil || a == nil {
 		return
 	}
 	rf := bgp.AfiSafiToRouteFamily(uint16(a.Family.Afi), uint8(a.Family.Safi))
-	c.AfiSafiName = config.AfiSafiType(rf.String())
+	c.AfiSafiName = oc.AfiSafiType(rf.String())
 	c.Enabled = a.Enabled
 }
 
-func readAfiSafiStateFromAPIStruct(s *config.AfiSafiState, a *api.AfiSafiConfig) {
+func readAfiSafiStateFromAPIStruct(s *oc.AfiSafiState, a *api.AfiSafiConfig) {
 	if s == nil || a == nil {
 		return
 	}
@@ -527,23 +527,23 @@ func readAfiSafiStateFromAPIStruct(s *config.AfiSafiState, a *api.AfiSafiConfig)
 	s.Family = bgp.AfiSafiToRouteFamily(uint16(a.Family.Afi), uint8(a.Family.Safi))
 }
 
-func readPrefixLimitFromAPIStruct(c *config.PrefixLimit, a *api.PrefixLimit) {
+func readPrefixLimitFromAPIStruct(c *oc.PrefixLimit, a *api.PrefixLimit) {
 	if c == nil || a == nil {
 		return
 	}
 	c.Config.MaxPrefixes = a.MaxPrefixes
-	c.Config.ShutdownThresholdPct = config.Percentage(a.ShutdownThresholdPct)
+	c.Config.ShutdownThresholdPct = oc.Percentage(a.ShutdownThresholdPct)
 }
 
-func readApplyPolicyFromAPIStruct(c *config.ApplyPolicy, a *api.ApplyPolicy) {
+func readApplyPolicyFromAPIStruct(c *oc.ApplyPolicy, a *api.ApplyPolicy) {
 	if c == nil || a == nil {
 		return
 	}
-	f := func(a api.RouteAction) config.DefaultPolicyType {
+	f := func(a api.RouteAction) oc.DefaultPolicyType {
 		if a == api.RouteAction_ACCEPT {
-			return config.DEFAULT_POLICY_TYPE_ACCEPT_ROUTE
+			return oc.DEFAULT_POLICY_TYPE_ACCEPT_ROUTE
 		} else if a == api.RouteAction_REJECT {
-			return config.DEFAULT_POLICY_TYPE_REJECT_ROUTE
+			return oc.DEFAULT_POLICY_TYPE_REJECT_ROUTE
 		}
 		return ""
 	}
@@ -568,7 +568,7 @@ func readApplyPolicyFromAPIStruct(c *config.ApplyPolicy, a *api.ApplyPolicy) {
 	}
 }
 
-func readRouteSelectionOptionsFromAPIStruct(c *config.RouteSelectionOptions, a *api.RouteSelectionOptions) {
+func readRouteSelectionOptionsFromAPIStruct(c *oc.RouteSelectionOptions, a *api.RouteSelectionOptions) {
 	if c == nil || a == nil {
 		return
 	}
@@ -582,7 +582,7 @@ func readRouteSelectionOptionsFromAPIStruct(c *config.RouteSelectionOptions, a *
 	}
 }
 
-func readUseMultiplePathsFromAPIStruct(c *config.UseMultiplePaths, a *api.UseMultiplePaths) {
+func readUseMultiplePathsFromAPIStruct(c *oc.UseMultiplePaths, a *api.UseMultiplePaths) {
 	if c == nil || a == nil {
 		return
 	}
@@ -590,23 +590,23 @@ func readUseMultiplePathsFromAPIStruct(c *config.UseMultiplePaths, a *api.UseMul
 		c.Config.Enabled = a.Config.Enabled
 	}
 	if a.Ebgp != nil && a.Ebgp.Config != nil {
-		c.Ebgp = config.Ebgp{
-			Config: config.EbgpConfig{
+		c.Ebgp = oc.Ebgp{
+			Config: oc.EbgpConfig{
 				AllowMultipleAs: a.Ebgp.Config.AllowMultipleAsn,
 				MaximumPaths:    a.Ebgp.Config.MaximumPaths,
 			},
 		}
 	}
 	if a.Ibgp != nil && a.Ibgp.Config != nil {
-		c.Ibgp = config.Ibgp{
-			Config: config.IbgpConfig{
+		c.Ibgp = oc.Ibgp{
+			Config: oc.IbgpConfig{
 				MaximumPaths: a.Ibgp.Config.MaximumPaths,
 			},
 		}
 	}
 }
 
-func readRouteTargetMembershipFromAPIStruct(c *config.RouteTargetMembership, a *api.RouteTargetMembership) {
+func readRouteTargetMembershipFromAPIStruct(c *oc.RouteTargetMembership, a *api.RouteTargetMembership) {
 	if c == nil || a == nil {
 		return
 	}
@@ -615,7 +615,7 @@ func readRouteTargetMembershipFromAPIStruct(c *config.RouteTargetMembership, a *
 	}
 }
 
-func readLongLivedGracefulRestartFromAPIStruct(c *config.LongLivedGracefulRestart, a *api.LongLivedGracefulRestart) {
+func readLongLivedGracefulRestartFromAPIStruct(c *oc.LongLivedGracefulRestart, a *api.LongLivedGracefulRestart) {
 	if c == nil || a == nil {
 		return
 	}
@@ -625,7 +625,7 @@ func readLongLivedGracefulRestartFromAPIStruct(c *config.LongLivedGracefulRestar
 	}
 }
 
-func readAddPathsFromAPIStruct(c *config.AddPaths, a *api.AddPaths) {
+func readAddPathsFromAPIStruct(c *oc.AddPaths, a *api.AddPaths) {
 	if c == nil || a == nil {
 		return
 	}
@@ -635,8 +635,8 @@ func readAddPathsFromAPIStruct(c *config.AddPaths, a *api.AddPaths) {
 	}
 }
 
-func newNeighborFromAPIStruct(a *api.Peer) (*config.Neighbor, error) {
-	pconf := &config.Neighbor{}
+func newNeighborFromAPIStruct(a *api.Peer) (*oc.Neighbor, error) {
+	pconf := &oc.Neighbor{}
 	if a.Conf != nil {
 		pconf.Config.PeerAs = a.Conf.PeerAsn
 		pconf.Config.LocalAs = a.Conf.LocalAsn
@@ -644,7 +644,7 @@ func newNeighborFromAPIStruct(a *api.Peer) (*config.Neighbor, error) {
 		pconf.Config.RouteFlapDamping = a.Conf.RouteFlapDamping
 		pconf.Config.Description = a.Conf.Description
 		pconf.Config.PeerGroup = a.Conf.PeerGroup
-		pconf.Config.PeerType = config.IntToPeerTypeMap[int(a.Conf.Type)]
+		pconf.Config.PeerType = oc.IntToPeerTypeMap[int(a.Conf.Type)]
 		pconf.Config.NeighborAddress = a.Conf.NeighborAddress
 		pconf.Config.AdminDown = a.Conf.AdminDown
 		pconf.Config.NeighborInterface = a.Conf.NeighborInterface
@@ -655,9 +655,9 @@ func newNeighborFromAPIStruct(a *api.Peer) (*config.Neighbor, error) {
 
 		switch a.Conf.RemovePrivate {
 		case api.RemovePrivate_REMOVE_ALL:
-			pconf.Config.RemovePrivateAs = config.REMOVE_PRIVATE_AS_OPTION_ALL
+			pconf.Config.RemovePrivateAs = oc.REMOVE_PRIVATE_AS_OPTION_ALL
 		case api.RemovePrivate_REPLACE:
-			pconf.Config.RemovePrivateAs = config.REMOVE_PRIVATE_AS_OPTION_REPLACE
+			pconf.Config.RemovePrivateAs = oc.REMOVE_PRIVATE_AS_OPTION_REPLACE
 		}
 
 		if a.State != nil {
@@ -676,7 +676,7 @@ func newNeighborFromAPIStruct(a *api.Peer) (*config.Neighbor, error) {
 		}
 
 		for _, af := range a.AfiSafis {
-			afiSafi := config.AfiSafi{}
+			afiSafi := oc.AfiSafi{}
 			readMpGracefulRestartFromAPIStruct(&afiSafi.MpGracefulRestart, af.MpGracefulRestart)
 			readAfiSafiConfigFromAPIStruct(&afiSafi.Config, af.Config)
 			readAfiSafiStateFromAPIStruct(&afiSafi.State, af.Config)
@@ -705,7 +705,7 @@ func newNeighborFromAPIStruct(a *api.Peer) (*config.Neighbor, error) {
 		}
 	}
 	if a.RouteReflector != nil {
-		pconf.RouteReflector.Config.RouteReflectorClusterId = config.RrClusterIdType(a.RouteReflector.RouteReflectorClusterId)
+		pconf.RouteReflector.Config.RouteReflectorClusterId = oc.RrClusterIdType(a.RouteReflector.RouteReflectorClusterId)
 		pconf.RouteReflector.Config.RouteReflectorClient = a.RouteReflector.RouteReflectorClient
 	}
 	if a.RouteServer != nil {
@@ -728,6 +728,7 @@ func newNeighborFromAPIStruct(a *api.Peer) (*config.Neighbor, error) {
 		pconf.Transport.Config.RemotePort = uint16(a.Transport.RemotePort)
 		pconf.Transport.Config.LocalPort = uint16(a.Transport.LocalPort)
 		pconf.Transport.Config.BindInterface = a.Transport.BindInterface
+		pconf.Transport.Config.TcpMss = uint16(a.Transport.TcpMss)
 	}
 	if a.EbgpMultihop != nil {
 		pconf.EbgpMultihop.Config.Enabled = a.EbgpMultihop.Enabled
@@ -738,11 +739,11 @@ func newNeighborFromAPIStruct(a *api.Peer) (*config.Neighbor, error) {
 		pconf.TtlSecurity.Config.TtlMin = uint8(a.TtlSecurity.TtlMin)
 	}
 	if a.State != nil {
-		pconf.State.SessionState = config.SessionState(strings.ToUpper(string(a.State.SessionState)))
-		pconf.State.AdminState = config.IntToAdminStateMap[int(a.State.AdminState)]
+		pconf.State.SessionState = oc.SessionState(strings.ToUpper(string(a.State.SessionState)))
+		pconf.State.AdminState = oc.IntToAdminStateMap[int(a.State.AdminState)]
 
 		pconf.State.PeerAs = a.State.PeerAsn
-		pconf.State.PeerType = config.IntToPeerTypeMap[int(a.State.Type)]
+		pconf.State.PeerType = oc.IntToPeerTypeMap[int(a.State.Type)]
 		pconf.State.NeighborAddress = a.State.NeighborAddress
 
 		if a.State.Messages != nil {
@@ -768,8 +769,8 @@ func newNeighborFromAPIStruct(a *api.Peer) (*config.Neighbor, error) {
 	return pconf, nil
 }
 
-func newPeerGroupFromAPIStruct(a *api.PeerGroup) (*config.PeerGroup, error) {
-	pconf := &config.PeerGroup{}
+func newPeerGroupFromAPIStruct(a *api.PeerGroup) (*oc.PeerGroup, error) {
+	pconf := &oc.PeerGroup{}
 	if a.Conf != nil {
 		pconf.Config.PeerAs = a.Conf.PeerAsn
 		pconf.Config.LocalAs = a.Conf.LocalAsn
@@ -780,13 +781,13 @@ func newPeerGroupFromAPIStruct(a *api.PeerGroup) (*config.PeerGroup, error) {
 
 		switch a.Conf.RemovePrivate {
 		case api.RemovePrivate_REMOVE_ALL:
-			pconf.Config.RemovePrivateAs = config.REMOVE_PRIVATE_AS_OPTION_ALL
+			pconf.Config.RemovePrivateAs = oc.REMOVE_PRIVATE_AS_OPTION_ALL
 		case api.RemovePrivate_REPLACE:
-			pconf.Config.RemovePrivateAs = config.REMOVE_PRIVATE_AS_OPTION_REPLACE
+			pconf.Config.RemovePrivateAs = oc.REMOVE_PRIVATE_AS_OPTION_REPLACE
 		}
 
 		for _, af := range a.AfiSafis {
-			afiSafi := config.AfiSafi{}
+			afiSafi := oc.AfiSafi{}
 			readMpGracefulRestartFromAPIStruct(&afiSafi.MpGracefulRestart, af.MpGracefulRestart)
 			readAfiSafiConfigFromAPIStruct(&afiSafi.Config, af.Config)
 			readAfiSafiStateFromAPIStruct(&afiSafi.State, af.Config)
@@ -815,7 +816,7 @@ func newPeerGroupFromAPIStruct(a *api.PeerGroup) (*config.PeerGroup, error) {
 		}
 	}
 	if a.RouteReflector != nil {
-		pconf.RouteReflector.Config.RouteReflectorClusterId = config.RrClusterIdType(a.RouteReflector.RouteReflectorClusterId)
+		pconf.RouteReflector.Config.RouteReflectorClusterId = oc.RrClusterIdType(a.RouteReflector.RouteReflectorClusterId)
 		pconf.RouteReflector.Config.RouteReflectorClient = a.RouteReflector.RouteReflectorClient
 	}
 	if a.RouteServer != nil {
@@ -836,6 +837,7 @@ func newPeerGroupFromAPIStruct(a *api.PeerGroup) (*config.PeerGroup, error) {
 		pconf.Transport.Config.LocalAddress = a.Transport.LocalAddress
 		pconf.Transport.Config.PassiveMode = a.Transport.PassiveMode
 		pconf.Transport.Config.RemotePort = uint16(a.Transport.RemotePort)
+		pconf.Transport.Config.TcpMss = uint16(a.Transport.TcpMss)
 	}
 	if a.EbgpMultihop != nil {
 		pconf.EbgpMultihop.Config.Enabled = a.EbgpMultihop.Enabled
@@ -849,7 +851,7 @@ func newPeerGroupFromAPIStruct(a *api.PeerGroup) (*config.PeerGroup, error) {
 		pconf.State.TotalPaths = a.Info.TotalPaths
 		pconf.State.TotalPrefixes = a.Info.TotalPrefixes
 		pconf.State.PeerAs = a.Info.PeerAsn
-		pconf.State.PeerType = config.IntToPeerTypeMap[int(a.Info.Type)]
+		pconf.State.PeerType = oc.IntToPeerTypeMap[int(a.Info.Type)]
 	}
 	return pconf, nil
 }
@@ -903,24 +905,24 @@ func newPrefixFromApiStruct(a *api.Prefix) (*table.Prefix, error) {
 	}, nil
 }
 
-func newConfigPrefixFromAPIStruct(a *api.Prefix) (*config.Prefix, error) {
+func newConfigPrefixFromAPIStruct(a *api.Prefix) (*oc.Prefix, error) {
 	_, prefix, err := net.ParseCIDR(a.IpPrefix)
 	if err != nil {
 		return nil, err
 	}
-	return &config.Prefix{
+	return &oc.Prefix{
 		IpPrefix:        prefix.String(),
 		MasklengthRange: fmt.Sprintf("%d..%d", a.MaskLengthMin, a.MaskLengthMax),
 	}, nil
 }
 
-func newConfigDefinedSetsFromApiStruct(a []*api.DefinedSet) (*config.DefinedSets, error) {
-	ps := make([]config.PrefixSet, 0)
-	ns := make([]config.NeighborSet, 0)
-	as := make([]config.AsPathSet, 0)
-	cs := make([]config.CommunitySet, 0)
-	es := make([]config.ExtCommunitySet, 0)
-	ls := make([]config.LargeCommunitySet, 0)
+func newConfigDefinedSetsFromApiStruct(a []*api.DefinedSet) (*oc.DefinedSets, error) {
+	ps := make([]oc.PrefixSet, 0)
+	ns := make([]oc.NeighborSet, 0)
+	as := make([]oc.AsPathSet, 0)
+	cs := make([]oc.CommunitySet, 0)
+	es := make([]oc.ExtCommunitySet, 0)
+	ls := make([]oc.LargeCommunitySet, 0)
 
 	for _, ds := range a {
 		if ds.Name == "" {
@@ -928,7 +930,7 @@ func newConfigDefinedSetsFromApiStruct(a []*api.DefinedSet) (*config.DefinedSets
 		}
 		switch table.DefinedType(ds.DefinedType) {
 		case table.DEFINED_TYPE_PREFIX:
-			prefixes := make([]config.Prefix, 0, len(ds.Prefixes))
+			prefixes := make([]oc.Prefix, 0, len(ds.Prefixes))
 			for _, p := range ds.Prefixes {
 				prefix, err := newConfigPrefixFromAPIStruct(p)
 				if err != nil {
@@ -936,32 +938,32 @@ func newConfigDefinedSetsFromApiStruct(a []*api.DefinedSet) (*config.DefinedSets
 				}
 				prefixes = append(prefixes, *prefix)
 			}
-			ps = append(ps, config.PrefixSet{
+			ps = append(ps, oc.PrefixSet{
 				PrefixSetName: ds.Name,
 				PrefixList:    prefixes,
 			})
 		case table.DEFINED_TYPE_NEIGHBOR:
-			ns = append(ns, config.NeighborSet{
+			ns = append(ns, oc.NeighborSet{
 				NeighborSetName:  ds.Name,
 				NeighborInfoList: ds.List,
 			})
 		case table.DEFINED_TYPE_AS_PATH:
-			as = append(as, config.AsPathSet{
+			as = append(as, oc.AsPathSet{
 				AsPathSetName: ds.Name,
 				AsPathList:    ds.List,
 			})
 		case table.DEFINED_TYPE_COMMUNITY:
-			cs = append(cs, config.CommunitySet{
+			cs = append(cs, oc.CommunitySet{
 				CommunitySetName: ds.Name,
 				CommunityList:    ds.List,
 			})
 		case table.DEFINED_TYPE_EXT_COMMUNITY:
-			es = append(es, config.ExtCommunitySet{
+			es = append(es, oc.ExtCommunitySet{
 				ExtCommunitySetName: ds.Name,
 				ExtCommunityList:    ds.List,
 			})
 		case table.DEFINED_TYPE_LARGE_COMMUNITY:
-			ls = append(ls, config.LargeCommunitySet{
+			ls = append(ls, oc.LargeCommunitySet{
 				LargeCommunitySetName: ds.Name,
 				LargeCommunityList:    ds.List,
 			})
@@ -970,10 +972,10 @@ func newConfigDefinedSetsFromApiStruct(a []*api.DefinedSet) (*config.DefinedSets
 		}
 	}
 
-	return &config.DefinedSets{
+	return &oc.DefinedSets{
 		PrefixSets:   ps,
 		NeighborSets: ns,
-		BgpDefinedSets: config.BgpDefinedSets{
+		BgpDefinedSets: oc.BgpDefinedSets{
 			AsPathSets:         as,
 			CommunitySets:      cs,
 			ExtCommunitySets:   es,
@@ -1008,22 +1010,22 @@ func newDefinedSetFromApiStruct(a *api.DefinedSet) (table.DefinedSet, error) {
 		}
 		return table.NewNeighborSetFromApiStruct(a.Name, list)
 	case table.DEFINED_TYPE_AS_PATH:
-		return table.NewAsPathSet(config.AsPathSet{
+		return table.NewAsPathSet(oc.AsPathSet{
 			AsPathSetName: a.Name,
 			AsPathList:    a.List,
 		})
 	case table.DEFINED_TYPE_COMMUNITY:
-		return table.NewCommunitySet(config.CommunitySet{
+		return table.NewCommunitySet(oc.CommunitySet{
 			CommunitySetName: a.Name,
 			CommunityList:    a.List,
 		})
 	case table.DEFINED_TYPE_EXT_COMMUNITY:
-		return table.NewExtCommunitySet(config.ExtCommunitySet{
+		return table.NewExtCommunitySet(oc.ExtCommunitySet{
 			ExtCommunitySetName: a.Name,
 			ExtCommunityList:    a.List,
 		})
 	case table.DEFINED_TYPE_LARGE_COMMUNITY:
-		return table.NewLargeCommunitySet(config.LargeCommunitySet{
+		return table.NewLargeCommunitySet(oc.LargeCommunitySet{
 			LargeCommunitySetName: a.Name,
 			LargeCommunityList:    a.List,
 		})
@@ -1055,18 +1057,18 @@ func (s *server) DeleteDefinedSet(ctx context.Context, r *api.DeleteDefinedSetRe
 
 var _regexpMedActionType = regexp.MustCompile(`([+-]?)(\d+)`)
 
-func matchSetOptionsRestrictedTypeToAPI(t config.MatchSetOptionsRestrictedType) api.MatchSet_Type {
+func matchSetOptionsRestrictedTypeToAPI(t oc.MatchSetOptionsRestrictedType) api.MatchSet_Type {
 	t = t.DefaultAsNeeded()
 	switch t {
-	case config.MATCH_SET_OPTIONS_RESTRICTED_TYPE_ANY:
+	case oc.MATCH_SET_OPTIONS_RESTRICTED_TYPE_ANY:
 		return api.MatchSet_ANY
-	case config.MATCH_SET_OPTIONS_RESTRICTED_TYPE_INVERT:
+	case oc.MATCH_SET_OPTIONS_RESTRICTED_TYPE_INVERT:
 		return api.MatchSet_INVERT
 	}
 	return api.MatchSet_ANY
 }
 
-func toStatementApi(s *config.Statement) *api.Statement {
+func toStatementApi(s *oc.Statement) *api.Statement {
 	cs := &api.Conditions{}
 	if s.Conditions.MatchPrefixSet.PrefixSet != "" {
 		cs.PrefixSet = &api.MatchSet{
@@ -1130,9 +1132,9 @@ func toStatementApi(s *config.Statement) *api.Statement {
 	as := &api.Actions{
 		RouteAction: func() api.RouteAction {
 			switch s.Actions.RouteDisposition {
-			case config.ROUTE_DISPOSITION_ACCEPT_ROUTE:
+			case oc.ROUTE_DISPOSITION_ACCEPT_ROUTE:
 				return api.RouteAction_ACCEPT
-			case config.ROUTE_DISPOSITION_REJECT_ROUTE:
+			case oc.ROUTE_DISPOSITION_REJECT_ROUTE:
 				return api.RouteAction_REJECT
 			}
 			return api.RouteAction_NONE
@@ -1142,7 +1144,7 @@ func toStatementApi(s *config.Statement) *api.Statement {
 				return nil
 			}
 			return &api.CommunityAction{
-				Type:        api.CommunityAction_Type(config.BgpSetCommunityOptionTypeToIntMap[config.BgpSetCommunityOptionType(s.Actions.BgpActions.SetCommunity.Options)]),
+				Type:        api.CommunityAction_Type(oc.BgpSetCommunityOptionTypeToIntMap[oc.BgpSetCommunityOptionType(s.Actions.BgpActions.SetCommunity.Options)]),
 				Communities: s.Actions.BgpActions.SetCommunity.SetCommunityMethod.CommunitiesList}
 		}(),
 		Med: func() *api.MedAction {
@@ -1190,7 +1192,7 @@ func toStatementApi(s *config.Statement) *api.Statement {
 				return nil
 			}
 			return &api.CommunityAction{
-				Type:        api.CommunityAction_Type(config.BgpSetCommunityOptionTypeToIntMap[config.BgpSetCommunityOptionType(s.Actions.BgpActions.SetExtCommunity.Options)]),
+				Type:        api.CommunityAction_Type(oc.BgpSetCommunityOptionTypeToIntMap[oc.BgpSetCommunityOptionType(s.Actions.BgpActions.SetExtCommunity.Options)]),
 				Communities: s.Actions.BgpActions.SetExtCommunity.SetExtCommunityMethod.CommunitiesList,
 			}
 		}(),
@@ -1199,7 +1201,7 @@ func toStatementApi(s *config.Statement) *api.Statement {
 				return nil
 			}
 			return &api.CommunityAction{
-				Type:        api.CommunityAction_Type(config.BgpSetCommunityOptionTypeToIntMap[config.BgpSetCommunityOptionType(s.Actions.BgpActions.SetLargeCommunity.Options)]),
+				Type:        api.CommunityAction_Type(oc.BgpSetCommunityOptionTypeToIntMap[oc.BgpSetCommunityOptionType(s.Actions.BgpActions.SetLargeCommunity.Options)]),
 				Communities: s.Actions.BgpActions.SetLargeCommunity.SetLargeCommunityMethod.CommunitiesList,
 			}
 		}(),
@@ -1236,28 +1238,28 @@ func toStatementApi(s *config.Statement) *api.Statement {
 	}
 }
 
-func toConfigMatchSetOption(a api.MatchSet_Type) (config.MatchSetOptionsType, error) {
-	var typ config.MatchSetOptionsType
+func toConfigMatchSetOption(a api.MatchSet_Type) (oc.MatchSetOptionsType, error) {
+	var typ oc.MatchSetOptionsType
 	switch a {
 	case api.MatchSet_ANY:
-		typ = config.MATCH_SET_OPTIONS_TYPE_ANY
+		typ = oc.MATCH_SET_OPTIONS_TYPE_ANY
 	case api.MatchSet_ALL:
-		typ = config.MATCH_SET_OPTIONS_TYPE_ALL
+		typ = oc.MATCH_SET_OPTIONS_TYPE_ALL
 	case api.MatchSet_INVERT:
-		typ = config.MATCH_SET_OPTIONS_TYPE_INVERT
+		typ = oc.MATCH_SET_OPTIONS_TYPE_INVERT
 	default:
 		return typ, fmt.Errorf("invalid match type")
 	}
 	return typ, nil
 }
 
-func toConfigMatchSetOptionRestricted(a api.MatchSet_Type) (config.MatchSetOptionsRestrictedType, error) {
-	var typ config.MatchSetOptionsRestrictedType
+func toConfigMatchSetOptionRestricted(a api.MatchSet_Type) (oc.MatchSetOptionsRestrictedType, error) {
+	var typ oc.MatchSetOptionsRestrictedType
 	switch a {
 	case api.MatchSet_ANY:
-		typ = config.MATCH_SET_OPTIONS_RESTRICTED_TYPE_ANY
+		typ = oc.MATCH_SET_OPTIONS_RESTRICTED_TYPE_ANY
 	case api.MatchSet_INVERT:
-		typ = config.MATCH_SET_OPTIONS_RESTRICTED_TYPE_INVERT
+		typ = oc.MATCH_SET_OPTIONS_RESTRICTED_TYPE_INVERT
 	default:
 		return typ, fmt.Errorf("invalid match type")
 	}
@@ -1272,7 +1274,7 @@ func newPrefixConditionFromApiStruct(a *api.MatchSet) (*table.PrefixCondition, e
 	if err != nil {
 		return nil, err
 	}
-	c := config.MatchPrefixSet{
+	c := oc.MatchPrefixSet{
 		PrefixSet:       a.Name,
 		MatchSetOptions: typ,
 	}
@@ -1287,7 +1289,7 @@ func newNeighborConditionFromApiStruct(a *api.MatchSet) (*table.NeighborConditio
 	if err != nil {
 		return nil, err
 	}
-	c := config.MatchNeighborSet{
+	c := oc.MatchNeighborSet{
 		NeighborSet:     a.Name,
 		MatchSetOptions: typ,
 	}
@@ -1298,8 +1300,8 @@ func newAsPathLengthConditionFromApiStruct(a *api.AsPathLength) (*table.AsPathLe
 	if a == nil {
 		return nil, nil
 	}
-	return table.NewAsPathLengthCondition(config.AsPathLength{
-		Operator: config.IntToAttributeComparisonMap[int(a.Type)],
+	return table.NewAsPathLengthCondition(oc.AsPathLength{
+		Operator: oc.IntToAttributeComparisonMap[int(a.Type)],
 		Value:    a.Length,
 	})
 }
@@ -1312,7 +1314,7 @@ func newAsPathConditionFromApiStruct(a *api.MatchSet) (*table.AsPathCondition, e
 	if err != nil {
 		return nil, err
 	}
-	c := config.MatchAsPathSet{
+	c := oc.MatchAsPathSet{
 		AsPathSet:       a.Name,
 		MatchSetOptions: typ,
 	}
@@ -1323,14 +1325,14 @@ func newRpkiValidationConditionFromApiStruct(a int32) (*table.RpkiValidationCond
 	if a < 1 {
 		return nil, nil
 	}
-	return table.NewRpkiValidationCondition(config.IntToRpkiValidationResultTypeMap[int(a)])
+	return table.NewRpkiValidationCondition(oc.IntToRpkiValidationResultTypeMap[int(a)])
 }
 
 func newRouteTypeConditionFromApiStruct(a api.Conditions_RouteType) (*table.RouteTypeCondition, error) {
 	if a == 0 {
 		return nil, nil
 	}
-	typ, ok := config.IntToRouteTypeMap[int(a)]
+	typ, ok := oc.IntToRouteTypeMap[int(a)]
 	if !ok {
 		return nil, fmt.Errorf("invalid route type: %d", a)
 	}
@@ -1345,7 +1347,7 @@ func newCommunityConditionFromApiStruct(a *api.MatchSet) (*table.CommunityCondit
 	if err != nil {
 		return nil, err
 	}
-	c := config.MatchCommunitySet{
+	c := oc.MatchCommunitySet{
 		CommunitySet:    a.Name,
 		MatchSetOptions: typ,
 	}
@@ -1360,7 +1362,7 @@ func newExtCommunityConditionFromApiStruct(a *api.MatchSet) (*table.ExtCommunity
 	if err != nil {
 		return nil, err
 	}
-	c := config.MatchExtCommunitySet{
+	c := oc.MatchExtCommunitySet{
 		ExtCommunitySet: a.Name,
 		MatchSetOptions: typ,
 	}
@@ -1375,7 +1377,7 @@ func newLargeCommunityConditionFromApiStruct(a *api.MatchSet) (*table.LargeCommu
 	if err != nil {
 		return nil, err
 	}
-	c := config.MatchLargeCommunitySet{
+	c := oc.MatchLargeCommunitySet{
 		LargeCommunitySet: a.Name,
 		MatchSetOptions:   typ,
 	}
@@ -1394,11 +1396,11 @@ func newAfiSafiInConditionFromApiStruct(a []*api.Family) (*table.AfiSafiInCondit
 	if a == nil {
 		return nil, nil
 	}
-	afiSafiTypes := make([]config.AfiSafiType, 0, len(a))
+	afiSafiTypes := make([]oc.AfiSafiType, 0, len(a))
 	for _, aType := range a {
 		rf := bgp.AfiSafiToRouteFamily(uint16(aType.Afi), uint8(aType.Safi))
 		if configType, ok := bgp.AddressFamilyNameMap[bgp.RouteFamily(rf)]; ok {
-			afiSafiTypes = append(afiSafiTypes, config.AfiSafiType(configType))
+			afiSafiTypes = append(afiSafiTypes, oc.AfiSafiType(configType))
 		} else {
 			return nil, fmt.Errorf("unknown afi-safi-in type value: %v", aType)
 		}
@@ -1423,9 +1425,9 @@ func newCommunityActionFromApiStruct(a *api.CommunityAction) (*table.CommunityAc
 	if a == nil {
 		return nil, nil
 	}
-	return table.NewCommunityAction(config.SetCommunity{
-		Options: string(config.IntToBgpSetCommunityOptionTypeMap[int(a.Type)]),
-		SetCommunityMethod: config.SetCommunityMethod{
+	return table.NewCommunityAction(oc.SetCommunity{
+		Options: string(oc.IntToBgpSetCommunityOptionTypeMap[int(a.Type)]),
+		SetCommunityMethod: oc.SetCommunityMethod{
 			CommunitiesList: a.Communities,
 		},
 	})
@@ -1435,9 +1437,9 @@ func newExtCommunityActionFromApiStruct(a *api.CommunityAction) (*table.ExtCommu
 	if a == nil {
 		return nil, nil
 	}
-	return table.NewExtCommunityAction(config.SetExtCommunity{
-		Options: string(config.IntToBgpSetCommunityOptionTypeMap[int(a.Type)]),
-		SetExtCommunityMethod: config.SetExtCommunityMethod{
+	return table.NewExtCommunityAction(oc.SetExtCommunity{
+		Options: string(oc.IntToBgpSetCommunityOptionTypeMap[int(a.Type)]),
+		SetExtCommunityMethod: oc.SetExtCommunityMethod{
 			CommunitiesList: a.Communities,
 		},
 	})
@@ -1447,9 +1449,9 @@ func newLargeCommunityActionFromApiStruct(a *api.CommunityAction) (*table.LargeC
 	if a == nil {
 		return nil, nil
 	}
-	return table.NewLargeCommunityAction(config.SetLargeCommunity{
-		Options: config.IntToBgpSetCommunityOptionTypeMap[int(a.Type)],
-		SetLargeCommunityMethod: config.SetLargeCommunityMethod{
+	return table.NewLargeCommunityAction(oc.SetLargeCommunity{
+		Options: oc.IntToBgpSetCommunityOptionTypeMap[int(a.Type)],
+		SetLargeCommunityMethod: oc.SetLargeCommunityMethod{
 			CommunitiesList: a.Communities,
 		},
 	})
@@ -1473,7 +1475,7 @@ func newAsPathPrependActionFromApiStruct(a *api.AsPrependAction) (*table.AsPathP
 	if a == nil {
 		return nil, nil
 	}
-	return table.NewAsPathPrependAction(config.SetAsPathPrepend{
+	return table.NewAsPathPrependAction(oc.SetAsPathPrepend{
 		RepeatN: uint8(a.Repeat),
 		As: func() string {
 			if a.UseLeftMost {
@@ -1488,7 +1490,7 @@ func newNexthopActionFromApiStruct(a *api.NexthopAction) (*table.NexthopAction,
 	if a == nil {
 		return nil, nil
 	}
-	return table.NewNexthopAction(config.BgpNextHopType(
+	return table.NewNexthopAction(oc.BgpNextHopType(
 		func() string {
 			if a.Self {
 				return "self"
@@ -1622,11 +1624,11 @@ func (s *server) DeleteStatement(ctx context.Context, r *api.DeleteStatementRequ
 	return &emptypb.Empty{}, s.bgpServer.DeleteStatement(ctx, r)
 }
 
-func newConfigPolicyFromApiStruct(a *api.Policy) (*config.PolicyDefinition, error) {
+func newConfigPolicyFromApiStruct(a *api.Policy) (*oc.PolicyDefinition, error) {
 	if a.Name == "" {
 		return nil, fmt.Errorf("empty policy name")
 	}
-	stmts := make([]config.Statement, 0, len(a.Statements))
+	stmts := make([]oc.Statement, 0, len(a.Statements))
 	for idx, x := range a.Statements {
 		if x.Name == "" {
 			x.Name = fmt.Sprintf("%s_stmt%d", a.Name, idx)
@@ -1638,7 +1640,7 @@ func newConfigPolicyFromApiStruct(a *api.Policy) (*config.PolicyDefinition, erro
 		stmt := y.ToConfig()
 		stmts = append(stmts, *stmt)
 	}
-	return &config.PolicyDefinition{
+	return &oc.PolicyDefinition{
 		Name:       a.Name,
 		Statements: stmts,
 	}, nil
@@ -1726,10 +1728,10 @@ func defaultRouteType(d api.RouteAction) table.RouteType {
 	}
 }
 
-func toPolicyDefinition(policies []*api.Policy) []*config.PolicyDefinition {
-	l := make([]*config.PolicyDefinition, 0, len(policies))
+func toPolicyDefinition(policies []*api.Policy) []*oc.PolicyDefinition {
+	l := make([]*oc.PolicyDefinition, 0, len(policies))
 	for _, p := range policies {
-		l = append(l, &config.PolicyDefinition{Name: p.Name})
+		l = append(l, &oc.PolicyDefinition{Name: p.Name})
 	}
 	return l
 }
@@ -1750,17 +1752,17 @@ func (s *server) GetBgp(ctx context.Context, r *api.GetBgpRequest) (*api.GetBgpR
 	return s.bgpServer.GetBgp(ctx, r)
 }
 
-func newGlobalFromAPIStruct(a *api.Global) *config.Global {
-	families := make([]config.AfiSafi, 0, len(a.Families))
+func newGlobalFromAPIStruct(a *api.Global) *oc.Global {
+	families := make([]oc.AfiSafi, 0, len(a.Families))
 	for _, f := range a.Families {
-		name := config.IntToAfiSafiTypeMap[int(f)]
+		name := oc.IntToAfiSafiTypeMap[int(f)]
 		rf, _ := bgp.GetRouteFamily(string(name))
-		families = append(families, config.AfiSafi{
-			Config: config.AfiSafiConfig{
+		families = append(families, oc.AfiSafi{
+			Config: oc.AfiSafiConfig{
 				AfiSafiName: name,
 				Enabled:     true,
 			},
-			State: config.AfiSafiState{
+			State: oc.AfiSafiState{
 				AfiSafiName: name,
 				Enabled:     true,
 				Family:      rf,
@@ -1768,11 +1770,11 @@ func newGlobalFromAPIStruct(a *api.Global) *config.Global {
 		})
 	}
 
-	applyPolicy := &config.ApplyPolicy{}
+	applyPolicy := &oc.ApplyPolicy{}
 	readApplyPolicyFromAPIStruct(applyPolicy, a.ApplyPolicy)
 
-	global := &config.Global{
-		Config: config.GlobalConfig{
+	global := &oc.Global{
+		Config: oc.GlobalConfig{
 			As:               a.Asn,
 			RouterId:         a.RouterId,
 			Port:             a.ListenPort,
@@ -1780,15 +1782,15 @@ func newGlobalFromAPIStruct(a *api.Global) *config.Global {
 		},
 		ApplyPolicy: *applyPolicy,
 		AfiSafis:    families,
-		UseMultiplePaths: config.UseMultiplePaths{
-			Config: config.UseMultiplePathsConfig{
+		UseMultiplePaths: oc.UseMultiplePaths{
+			Config: oc.UseMultiplePathsConfig{
 				Enabled: a.UseMultiplePaths,
 			},
 		},
 	}
 	if a.RouteSelectionOptions != nil {
-		global.RouteSelectionOptions = config.RouteSelectionOptions{
-			Config: config.RouteSelectionOptionsConfig{
+		global.RouteSelectionOptions = oc.RouteSelectionOptions{
+			Config: oc.RouteSelectionOptionsConfig{
 				AlwaysCompareMed:         a.RouteSelectionOptions.AlwaysCompareMed,
 				IgnoreAsPathLength:       a.RouteSelectionOptions.IgnoreAsPathLength,
 				ExternalCompareRouterId:  a.RouteSelectionOptions.ExternalCompareRouterId,
@@ -1800,16 +1802,16 @@ func newGlobalFromAPIStruct(a *api.Global) *config.Global {
 		}
 	}
 	if a.DefaultRouteDistance != nil {
-		global.DefaultRouteDistance = config.DefaultRouteDistance{
-			Config: config.DefaultRouteDistanceConfig{
+		global.DefaultRouteDistance = oc.DefaultRouteDistance{
+			Config: oc.DefaultRouteDistanceConfig{
 				ExternalRouteDistance: uint8(a.DefaultRouteDistance.ExternalRouteDistance),
 				InternalRouteDistance: uint8(a.DefaultRouteDistance.InternalRouteDistance),
 			},
 		}
 	}
 	if a.Confederation != nil {
-		global.Confederation = config.Confederation{
-			Config: config.ConfederationConfig{
+		global.Confederation = oc.Confederation{
+			Config: oc.ConfederationConfig{
 				Enabled:      a.Confederation.Enabled,
 				Identifier:   a.Confederation.Identifier,
 				MemberAsList: a.Confederation.MemberAsList,
@@ -1817,8 +1819,8 @@ func newGlobalFromAPIStruct(a *api.Global) *config.Global {
 		}
 	}
 	if a.GracefulRestart != nil {
-		global.GracefulRestart = config.GracefulRestart{
-			Config: config.GracefulRestartConfig{
+		global.GracefulRestart = oc.GracefulRestart{
+			Config: oc.GracefulRestartConfig{
 				Enabled:             a.GracefulRestart.Enabled,
 				RestartTime:         uint16(a.GracefulRestart.RestartTime),
 				StaleRoutesTime:     float64(a.GracefulRestart.StaleRoutesTime),
